@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001009';
+our $VERSION   = '0.001010';
 
 has class =>
   is            => rw,
@@ -139,21 +139,7 @@ sub BUILD {
 
     for my $property ( 'builder', 'trigger' ) {
         if ( CodeRef->check( $self->$property ) ) {
-            my $coderef = $self->$property;
-            my $newname = do {
-                my $gen = $method_name_generator[$self->is_private]{$property};
-                local $_ = $self->name;
-                $gen->( $_ );
-            };
-            no strict 'refs';
-            my $classname;
-            if ( $self->class and $classname = $self->class->name ) {
-                *{"$classname\::$newname"} = $coderef;
-                $self->$property( $newname );
-            }
-            else {
-                croak "Could not install $property => CODEREF as Mite could not determine which class to install it into.";
-            }
+            $self->$property( 1 );
         }
     }
 
